@@ -37,7 +37,6 @@ class App(Generic[GenericDependencyContainer]):
 
     def __init__(self, dependency_container: GenericDependencyContainer,
                  dispatcher: IDispatcher = None, with_addons=False):
-
         self.name = dependency_container.app_config().app_name
         self.container = dependency_container
         self.sanic = Sanic(self.name, loads=orjson.loads, dumps=orjson.dumps,
@@ -185,11 +184,13 @@ class App(Generic[GenericDependencyContainer]):
     # def before_app_start(self):
     #     pass
 
-    def run(self, *args, **kwargs):
+    def run(self):
         self._set_sanic_confs()
         self._configure_sanic_main()
         self._configure_sanic_worker()
-        self.sanic.run(*args, **kwargs)
+        sanic_conf = self.container.app_config().sanic
+        start_args = sanic_conf.dict() if sanic_conf else {}
+        self.sanic.run(**start_args)
 
 
 AppListener = Callable[[App], None]
