@@ -1,14 +1,13 @@
 from abc import ABCMeta
 from copy import copy
-from typing import Any, Dict, TypeVar, Generic, Type
+from typing import Any
 
-import loguru
 from orjson import dumps, loads
 
 from web_foundation.config import GenericConfig
-from web_foundation.events.store import StoreUpdateEvent
-from web_foundation.kernel.channel import IChannel
-from web_foundation.kernel.resource import Resource
+from web_foundation.resources.stores.events import StoreUpdateEvent
+from web_foundation.kernel.messaging.channel import IChannel
+from web_foundation.resources.resource import Resource
 from web_foundation.utils.types import TypeJSON
 
 
